@@ -45,7 +45,7 @@ mice.impute.ri <- function(y, ry, x, ri.maxit = 10, ...)
     fit <- suppressWarnings(eval(expr))
     fit.sum <- summary.glm(fit)
     psi <- coef(fit)
-    rv <- t(chol(fit.sum$cov.unscaled))
+    rv <- t(chol(sym(fit.sum$cov.unscaled)))
     psi.star <- psi + rv %*% rnorm(ncol(rv))
     p <- 1/(1 + exp(-(xr %*% psi.star)))
     vec <- (runif(nrow(p)) <= p)
